==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/es_MX.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Elementos compartidos federados",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea agregar el elemento compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Elemento compartido remoto",
    "Remote share password" : "Contraseña del elemento compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Agregar elemento compartido remoto",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "El ID de la Nube Federada es inválido",
    "Server to server sharing is not enabled on this server" : "Compartir de servidor a servidor no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No fue posible establecer el elemento compartido federado. ",
    "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitud de elemento compartido Federado enviada, recibiras una invitación. Verifica tus notificaciones.",
    "The mountpoint name contains invalid characters." : "El nombre del punto de montaje contiene caracteres inválidos.",
    "Not allowed to create a federated share with the owner." : "No está permitido crear un elemento compartido federado con el dueño. ",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no confiable",
    "Could not authenticate to remote share, password might be wrong" : "No fue posible autenticarse ante el elemento compartido remoto, la contraseña puede estar incorrecta",
    "Storage not valid" : "Almacenamiento inválido",
    "Federated share added" : "Elemento compartido Federado agregado",
    "Couldn't add remote share" : "No fue posible agregar el elemento compartido remoto",
    "Sharing %s failed, because this item is already shared with %s" : "Se presentó una falla al compartir %s, porque este elemento ya se encuentra compartido con  %s",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
    "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Se presentó una falla al compartir  %s, no fue posible encontrar %s, tal vez el servidor no está alcanzable o usa un certificado auto-firmado.",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Has recibido \"%3$s\" como un elemento compartido remoto de %1$s (de parte de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Has recibido \"%3$s\" como un elemento compartido remoto de %1$s",
    "You received {share} as a remote share from {user}" : "Recibiste {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud, ver %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Sharing" : "Compartiendo",
    "Federated file sharing" : "Compartiendo archivos en federación",
    "Federated Cloud Sharing" : "Compartiendo en la Nube Federada",
    "Open documentation" : "Abrir documentación",
    "Adjust how people can share between servers." : "Ajustar cómo las personas pueden compartir entre servidores. ",
    "Allow users on this server to send shares to other servers" : "Permitirle a los usuarios de este servidor enviar elementos compartidos a otros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "¡Puedes compartir con cualquiera que use NextCloud, ownCloud o Pydio! Solo ingresa tu ID de Nube Federada en ventana de diálogo de compartir. Se ve algo así como person@cloud.example.com",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Add to your website" : "Agregar a tu sitio web",
    "Share with me via Nextcloud" : "Compartir conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Search global and public address book for users and let local users publish their data" : "Buscar una libreta de direcciones global y pública para los usuarios y permitir  a los usuarios locales publicar sus datos",
    "Share it:" : "Compartirlo:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/es_MX.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Elementos compartidos",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea agregar el elemento compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Elemento compartido remoto",
    "Remote share password" : "Contraseña del elemento compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Agregar elemento compartido remoto",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "El ID es inválido",
    "Server to server sharing is not enabled on this server" : "Compartir de servidor a servidor no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No fue posible establecer el elemento compartido. ",
    "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitud de elemento compartido Federado enviada, recibiras una invitación. Verifica tus notificaciones.",
    "The mountpoint name contains invalid characters." : "El nombre del punto de montaje contiene caracteres inválidos.",
    "Not allowed to create a federated share with the owner." : "No está permitido crear un elemento compartido federado con el dueño. ",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no de confianza",
    "Could not authenticate to remote share, password might be wrong" : "No fue posible autenticarse ante el elemento compartido remoto, la contraseña puede estar incorrecta",
    "Storage not valid" : "Almacenamiento inválido",
    "Federated share added" : "Elemento compartido Federado agregado",
    "Couldn't add remote share" : "No fue posible agregar el elemento compartido remoto",
    "Sharing %s failed, because this item is already shared with %s" : "Se presentó una falla al compartir %s, porque este elemento ya se encuentra compartido con  %s",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
    "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Se presentó una falla al compartir  %s, no fue posible encontrar %s, tal vez el servidor no está alcanzable o usa un certificado auto-firmado.",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Has recibido \"%3$s\" como un elemento compartido remoto de %1$s (de parte de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Has recibido \"%3$s\" como un elemento compartido remoto de %1$s",
    "You received {share} as a remote share from {user}" : "Recibiste {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud, ver %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Sharing" : "Compartiendo",
    "Federated file sharing" : "Compartir  elementos",
    "Federated Cloud Sharing" : "Compartiendo en la Nube Federada",
    "Open documentation" : "Abrir documentación",
    "Adjust how people can share between servers." : "Ajustar cómo las personas pueden compartir entre servidores. ",
    "Allow users on this server to send shares to other servers" : "Permitirle a los usuarios de este servidor enviar elementos compartidos a otros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "¡Puedes compartir con cualquiera que use NextCloud, ownCloud o Pydio! Solo ingresa tu ID de Nube Federada en ventana de diálogo de compartir. Se ve algo así como person@cloud.example.com",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Add to your website" : "Agregar a tu sitio web",
    "Share with me via Nextcloud" : "Compartir conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Search global and public address book for users and let local users publish their data" : "Buscar una libreta de direcciones global y pública para los usuarios y permitir  a los usuarios locales publicar sus datos"
},
"nplurals=2; plural=(n != 1);");
